pro LWC_CAL

loadct,39

path_DATA='C:\MEX\MEX-M-PFS-2-EDR-EXT1-V1.0\DATA\MARS\LWC\ORB260X\'
file_HK       = 'PFS_2604_MEAS_HK_LW.DAT'
file_HK_LBL   = 'PFS_2604_MEAS_HK_LW.LBL'

file_MEAS     = 'PFS_2604_MEAS_RAW_LW.DAT'
file_MEAS_LBL = 'PFS_2604_MEAS_RAW_LW.LBL'

;---------------------------------------------------------------------------
;-------------- Opening Hosekeeping File -----------------------------------

;    open_hk,file_HK,path_DATA,hk_struct

num = read_pfs_label(path_DATA+file_HK_LBL,'FILE_RECORDS')

hk_struct=read_pfs_hk(path_DATA+file_HK,num)

;---------------------

    ;-------------- Plotting Some Hosekeeping Informations ------------

     temp_min = min(hk_struct.T1_10V) <  min(hk_struct.T5_10V) < min(hk_struct.T8_10V)
     temp_max = max(hk_struct.T1_10V) >  max(hk_struct.T5_10V) > max(hk_struct.T8_10V)

     window,0,title='Hosekeeping - SCET time vs. Internal Temperature'
      plot,hk_struct.SCET_OBSERVATION_TIME,hk_struct.T1_10V,ys=1,yr=[temp_min,temp_max],back=255,col=0,title='PFS Temperatures',xtitle='SCET (sec)',  ytitle='Temperature (!eo!nK)'
       oplot,hk_struct.SCET_OBSERVATION_TIME,hk_struct.T5_10V,col=150
       oplot,hk_struct.SCET_OBSERVATION_TIME,hk_struct.T8_10V,col=240


;---------------------------------------------------------------------------
;-------------- Opening Data File ------------------------------------------

    data_points = read_pfs_label(path_DATA+file_MEAS_LBL,'ITEMS')

    raw_struct=read_pfs_data(path_DATA+file_MEAS,num,data_points)

   ;-------------- Plotting Some Data --------------------------------

    points=N_ELEMENTS(raw_struct(0).interferogram)

    mean_range=indgen(200)+200

    if points eq 16384 then yrange=[-1e5,1e5] else yrange=[-500,500]

    window,1,title='Raw Data'

    plot,indgen(2),ys=1,yr=yrange,xs=1,xr=[0,points],back=255,col=0,/nodata
      for i=0,num-1 do begin
        temp=raw_struct(i).interferogram
        temp2=temp-mean(temp(mean_range))
         oplot,temp2,color=(float(i)/num)*255.*10;,back=255
      endfor

;---------------------------------------------------------------------------


;---------------------------------------------------------------------------
;-------------- Opening Calibration Tables ---------------------------------

path_CAL_TABLES='C:\MEX\PDS_ARCHIVE\CALIB\LWC\'

file_DS_FWD_CAL_RAW_LW   = 'PFS_DS-FWD_CAL_RAW_LW.DAT'
file_DS_REV_CAL_RAW_LW   = 'PFS_DS-REV_CAL_RAW_LW.DAT'
file_RESP_FWD_CAL_RAW_LW = 'PFS_RESP-FWD_CAL_RAW_LW.DAT'
file_RESP_REV_CAL_RAW_LW = 'PFS_RESP-REV_CAL_RAW_LW.DAT'

DS_FWD_CAL_RAW_LW = read_ascii(path_CAL_TABLES+file_DS_FWD_CAL_RAW_LW)
DS_REV_CAL_RAW_LW = read_ascii(path_CAL_TABLES+file_DS_REV_CAL_RAW_LW)
RESP_FWD_CAL_RAW_LW   = read_ascii(path_CAL_TABLES+file_RESP_FWD_CAL_RAW_LW  )
RESP_REV_CAL_RAW_LW   = read_ascii(path_CAL_TABLES+file_RESP_REV_CAL_RAW_LW  )

;get_lun,lun
;openw,lun,file_DS_FWD_CAL_RAW_LW
;printf,lun,DS_FWD_CAL_RAW_LW,format='(E20.7,"   ",E20.7)'
;close,lun
;free_lun,lun

    DS_FWD_CAL_RAW_LW = DS_FWD_CAL_RAW_LW.(0)
    DS_REV_CAL_RAW_LW = DS_REV_CAL_RAW_LW.(0)
    RESP_FWD_CAL_RAW_LW   =   RESP_FWD_CAL_RAW_LW.(0)
    RESP_REV_CAL_RAW_LW   =   RESP_REV_CAL_RAW_LW.(0)

    window,2,title='Calibration Tables'
    !P.MULTI=[0,2,2]
        plot,DS_FWD_CAL_RAW_LW(0,*),DS_FWD_CAL_RAW_LW(1,*),back=255,col=0,xs=1,xr=[250,1600]
        plot,DS_REV_CAL_RAW_LW(0,*),DS_REV_CAL_RAW_LW(1,*),back=255,col=0,xs=1,xr=[250,1600]
        plot,  RESP_FWD_CAL_RAW_LW(0,*),  RESP_FWD_CAL_RAW_LW(1,*),back=255,col=0,xs=1,xr=[250,1600]
        plot,  RESP_REV_CAL_RAW_LW(0,*),  RESP_REV_CAL_RAW_LW(1,*),back=255,col=0,xs=1,xr=[250,1600]
    !P.MULTI=0

;---------------------------------------------------------------------------
;-------------- Calibration ------------------------------------------------


          lambda        = 263.928E-06*hk_struct.LDTEMPSW_10V + 1.13351
          spectral_step = 10000.00/(8192.00*lambda)
          x_axes        = indgen(points/2)
          x_axes        = Rebin(x_axes,points/2,num)
          x_axes        = x_axes*rebin(spectral_step,num,points/2)

         interferograms = raw_struct.interferogram
            Mean_Values = TOTAL(interferograms,1)/float(points)
                Mean_Values_rebinned=rebin(transpose(Mean_Values),points,num)
         interferograms = interferograms-Mean_Values_rebinned

         spectra        = abs(fft(interferograms,-1,DIMENSION=1))
            spectra     = spectra(0:points/2-1,*)

         ;Double Pendulum direction: 0=Forward, 1=Reverse
         Forward        = where(hk_struct.DPDIR_STATUS eq 0)
         Reverse        = where(hk_struct.DPDIR_STATUS eq 1)

         Deep_space     = spectra
            Deep_space(*,Forward)=rebin(transpose((DS_FWD_CAL_RAW_LW(1,*))),points/2,n_elements(Forward))
            Deep_space(*,Reverse)=rebin(transpose((DS_REV_CAL_RAW_LW(1,*))),points/2,n_elements(Reverse))

         Responsivity   = spectra
            Responsivity(*,Forward)=rebin(transpose((RESP_FWD_CAL_RAW_LW(1,*))),points/2,n_elements(Forward))
            Responsivity(*,Reverse)=rebin(transpose((RESP_REV_CAL_RAW_LW(1,*))),points/2,n_elements(Reverse))

         MarsRadiance   = (Deep_space - spectra)/Responsivity
           MarsRadiance = MarsRadiance*1E07

    window,3,title='Raw Data',xs=1200
         plot, indgen(2), color=0,back=255,xs=1,xr=[250,1400],ys=1,yr=[0,150]

             for i=300,340 do oplot, x_axes(*,i), MarsRadiance(*,i), color=254*(i/float(range*2))
             for i=300,340 do print,hk_struct(i).SCET_OBSERVATION_TIME

SCET_to_write = hk_struct(300:340).SCET_OBSERVATION_TIME  ;-- UINT  - 4 BYTES

HELP,SCET_to_julian_time(SCET_to_write(300:340)),SCET_to_write,x_axes(*,300:340), MarsRadiance(*,300:340)

end