;pro SWC_CAL

loadct,39

path_DATA='C:\MEX\MEX-M-PFS-2-EDR-EXT1-V1.0\DATA\MARS\SWC\ORB260X\'

file_HK       = 'PFS_2604_MEAS_HK_SW.DAT'
file_HK_LBL   = 'PFS_2604_MEAS_HK_SW.LBL'

file_MEAS     = 'PFS_2604_MEAS_RAW_SW.DAT'
file_MEAS_LBL = 'PFS_2604_MEAS_RAW_SW.LBL'

;---------------------------------------------------------------------------
;-------------- Opening Hosekeeping File -----------------------------------

;    open_hk,file_HK,path_DATA,hk_struct

num = read_pfs_label(path_DATA+file_HK_LBL,'FILE_RECORDS')

hk_struct=read_pfs_hk(path_DATA+file_HK,num)

;---------------------

    ;-------------- Plotting Some Hosekeeping Informations ------------

     temp_min = min(hk_struct.T1_10V) <  min(hk_struct.T5_10V) < min(hk_struct.T8_10V)
     temp_max = max(hk_struct.T1_10V) >  max(hk_struct.T5_10V) > max(hk_struct.T8_10V)

     window,0,title='Hosekeeping - SCET time vs. Internal Temperature'
      plot,hk_struct.SCET_OBSERVATION_TIME,hk_struct.T1_10V,ys=1,yr=[temp_min,temp_max],back=255,col=0,title='PFS Temperatures',xtitle='SCET (sec)',  ytitle='Temperature (!eo!nK)'
       oplot,hk_struct.SCET_OBSERVATION_TIME,hk_struct.T5_10V,col=150
       oplot,hk_struct.SCET_OBSERVATION_TIME,hk_struct.T8_10V,col=240

;---------------------------------------------------------------------------
;-------------- Opening Data File ------------------------------------------

    data_points = read_pfs_label(path_DATA+file_MEAS_LBL,'ITEMS')

    raw_struct=read_pfs_data(path_DATA+file_MEAS,num,data_points)

   ;-------------- Plotting Some Data --------------------------------

    points=N_ELEMENTS(raw_struct(0).interferogram)

    mean_range=indgen(200)+200

    if points eq 16384 then yrange=[-1e5,1e5] else yrange=[-500,500]

    window,1,title='Raw Data'

    plot,indgen(2),ys=1,yr=yrange,xs=1,xr=[0,points],back=255,col=0,/nodata
      for i=0,num-1 do begin
        temp=raw_struct(i).interferogram
        temp2=temp-mean(temp(mean_range))
         oplot,temp2,color=(float(i)/num)*255.*10;,back=255
      endfor
;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
;-------------- Opening Calibration Tables ---------------------------------


path_CAL_TABLES='C:\MEX\PDS_ARCHIVE\CALIB\SWC\LASER_OFF\'

file_DS_FWD_CAL_RAW_SW   = 'PFS_DS-FWD_CAL_RAW_SW.DAT'
file_DS_REV_CAL_RAW_SW   = 'PFS_DS-REV_CAL_RAW_SW.DAT'
file_RESP_FWD_CAL_RAW_SW = 'PFS_RESP-FWD_CAL_RAW_SW.DAT'
file_RESP_REV_CAL_RAW_SW = 'PFS_RESP-REV_CAL_RAW_SW.DAT'

DS_FWD_CAL_RAW_SW = read_ascii(path_CAL_TABLES+file_DS_FWD_CAL_RAW_SW)
DS_REV_CAL_RAW_SW = read_ascii(path_CAL_TABLES+file_DS_REV_CAL_RAW_SW)
RESP_FWD_CAL_RAW_SW   = read_ascii(path_CAL_TABLES+file_RESP_FWD_CAL_RAW_SW  )
RESP_REV_CAL_RAW_SW   = read_ascii(path_CAL_TABLES+file_RESP_REV_CAL_RAW_SW  )

;get_lun,lun
;openw,lun,file_DS_FWD_CAL_RAW_SW
;printf,lun,DS_FWD_CAL_RAW_SW,format='(E20.7,"   ",E20.7)'
;close,lun
;free_lun,lun

    DS_FWD_CAL_RAW_SW = DS_FWD_CAL_RAW_SW.(0)
    DS_REV_CAL_RAW_SW = DS_REV_CAL_RAW_SW.(0)
    RESP_FWD_CAL_RAW_SW   =   RESP_FWD_CAL_RAW_SW.(0)
    RESP_REV_CAL_RAW_SW   =   RESP_REV_CAL_RAW_SW.(0)

    xrange=[1800,8300]
    window,2,title='Calibration Tables',xs=900,ys=800
    !P.MULTI=[0,2,2]
        plot,DS_FWD_CAL_RAW_SW(0,*),DS_FWD_CAL_RAW_SW(1,*),back=255,col=0,xs=1,xr=xrange
        plot,DS_REV_CAL_RAW_SW(0,*),DS_REV_CAL_RAW_SW(1,*),back=255,col=0,xs=1,xr=xrange
        plot,  RESP_FWD_CAL_RAW_SW(0,*),  RESP_FWD_CAL_RAW_SW(1,*),back=255,col=0,xs=1,xr=xrange
        plot,  RESP_REV_CAL_RAW_SW(0,*),  RESP_REV_CAL_RAW_SW(1,*),back=255,col=0,xs=1,xr=xrange
    !P.MULTI=0

;---------------------------------------------------------------------------
;-------------- Calibration ------------------------------------------------

          lambda        = 6.06520e-005*hk_struct.LDTEMPSW_10V +  1.19203
          spectral_step = 1.04149*(10000.00/(8192.00*lambda))
          x_axes        = indgen(points/2)
          x_axes        = Rebin(x_axes,points/2,num)
          x_axes        = x_axes*rebin(spectral_step,num,points/2)

         interferograms = raw_struct.interferogram
            Mean_Values = TOTAL(interferograms,1)/float(points)
                Mean_Values_rebinned=rebin(transpose(Mean_Values),points,num)
         interferograms = interferograms-Mean_Values_rebinned

         spectra        = abs(fft(interferograms,-1,DIMENSION=1))
            spectra     = spectra(0:points/2-1,*)
             spectra     = spectra/rebin(transpose(2^hk_struct.SWGAIN_STATUS),points/2,n_elements(hk_struct))  ;- SENSOR GAIN

         ;Double Pendulum direction: 0=Forward, 1=Reverse
         Forward        = where(hk_struct.DPDIR_STATUS eq 0)
         Reverse        = where(hk_struct.DPDIR_STATUS eq 1)

         Deep_space     = spectra
            Deep_space(*,Forward)=rebin(transpose((DS_FWD_CAL_RAW_SW(1,*))),points/2,n_elements(Forward))
            Deep_space(*,Reverse)=rebin(transpose((DS_REV_CAL_RAW_SW(1,*))),points/2,n_elements(Reverse))

         Responsivity   = spectra
            Responsivity(*,Forward)=rebin(transpose((RESP_FWD_CAL_RAW_SW(1,*))),points/2,n_elements(Forward))
            Responsivity(*,Reverse)=rebin(transpose((RESP_REV_CAL_RAW_SW(1,*))),points/2,n_elements(Reverse))

         MarsRadiance   = (Deep_space + spectra)/Responsivity
          ; MarsRadiance = MarsRadiance*1E07

    window,3,title='Raw Data',xs=1200
         plot, indgen(2), color=0,back=255,xs=1,xr=[1800,8200],ys=1,yr=[0,10];,/YLOG
           ; for i=0,num-1 do oplot, x_axes(*,i), MarsRadiance(*,i), color=254*(i/float(num))

             for i=300,340 do oplot, x_axes(*,i), MarsRadiance(*,i), color=254*(i/80.)
             for i=300,340 do print,hk_struct(i).SCET_OBSERVATION_TIME

SCET = hk_struct(300:340).SCET_OBSERVATION_TIME  ;-- UINT  - 4 BYTES

HELP,SCET_to_julian_time(SCET(300:340)),SCET,x_axes(*,300:340), MarsRadiance(*,300:340)

end